@@ -22,7 +22,7 @@ class IdentityKey(models.Model):
     keyId = models.IntegerField()
     public = models.CharField(max_length=44)
     localId = models.IntegerField()
-    user = models.OneToOneField(User, on_delete=models.CASCADE, related_name='identityKey')
+    user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='identityKeys')
     cipher = models.CharField(max_length=88)
     salt = models.CharField(max_length=44)
     active = models.BooleanField(default=False)
@@ -37,7 +37,7 @@ class SignedPreKey(models.Model):
     keyId = models.IntegerField()
     public = models.CharField(max_length=44)
     signature = models.CharField(max_length=88)
-    user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='signedPreKey')
+    user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='signedPreKeys')
     cipher = models.CharField(max_length=88)
     salt = models.CharField(max_length=44)
     active = models.BooleanField(default=False)
