@@ -451,8 +451,8 @@ class StickProtocol():
         This Login method should be called after the user have verified their phone number and got their LimitedAccessToken.
         As a 2FA mechanism, the user need to provide their password (initial password hash). If the password is correct,
         return to the user their keys:
-            * Identity Key
-            * Signed Pre Key
+            * Identity Keys
+            * Signed Pre Keys
             * Pre Keys
             * Encrypting Sender Keys
         On the client-side, the password will be used to decrypt the private keys of the IdentityKey, SignedPreKey
@@ -460,7 +460,6 @@ class StickProtocol():
         The user will be able to re-establish their pairwise signal sessions. After that, the user can decrypt their ESKs
         as well as any of the DSKs the was sent to them, which they can fetch again from the server as needed.
         """
-        # user = self.User.objects.get(phone=data['phone'])
         if user.check_password(data['passwordHash']):  # This will create a "double-hash" and verify it
             signedPreKeysList = SignedPreKey.objects.filter(user=user)
             identityKeysList = IdentityKey.objects.filter(user=user)
